@@ -1,32 +1,28 @@
-# -*- coding:utf-8 -*-
-## src/common/connection_handlers.py
-##
-## Copyright (C) 2006 Dimitur Kirov <dkirov AT gmail.com>
-##                    Junglecow J <junglecow AT gmail.com>
-## Copyright (C) 2006-2007 Tomasz Melcer <liori AT exroot.org>
-##                         Travis Shirk <travis AT pobox.com>
-##                         Nikos Kouremenos <kourem AT gmail.com>
-## Copyright (C) 2006-2014 Yann Leboulanger <asterix AT lagaule.org>
-## Copyright (C) 2007 Julien Pivotto <roidelapluie AT gmail.com>
-## Copyright (C) 2007-2008 Brendan Taylor <whateley AT gmail.com>
-##                         Jean-Marie Traissard <jim AT lapin.org>
-##                         Stephan Erb <steve-e AT h3c.de>
-## Copyright (C) 2008 Jonathan Schleifer <js-gajim AT webkeks.org>
-##
-## This file is part of Gajim.
-##
-## Gajim is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published
-## by the Free Software Foundation; version 3 only.
-##
-## Gajim is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with Gajim. If not, see <http://www.gnu.org/licenses/>.
-##
+# Copyright (C) 2006 Dimitur Kirov <dkirov AT gmail.com>
+#                    Junglecow J <junglecow AT gmail.com>
+# Copyright (C) 2006-2007 Tomasz Melcer <liori AT exroot.org>
+#                         Travis Shirk <travis AT pobox.com>
+#                         Nikos Kouremenos <kourem AT gmail.com>
+# Copyright (C) 2006-2014 Yann Leboulanger <asterix AT lagaule.org>
+# Copyright (C) 2007 Julien Pivotto <roidelapluie AT gmail.com>
+# Copyright (C) 2007-2008 Brendan Taylor <whateley AT gmail.com>
+#                         Jean-Marie Traissard <jim AT lapin.org>
+#                         Stephan Erb <steve-e AT h3c.de>
+# Copyright (C) 2008 Jonathan Schleifer <js-gajim AT webkeks.org>
+#
+# This file is part of Gajim.
+#
+# Gajim is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published
+# by the Free Software Foundation; version 3 only.
+#
+# Gajim is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Gajim. If not, see <http://www.gnu.org/licenses/>.
 
 import socket
 import base64
@@ -80,7 +76,20 @@ class ConnectionBytestream:
 
     def __init__(self):
         app.ged.register_event_handler('file-request-received', ged.GUI1,
-            self._nec_file_request_received)
+                                       self._nec_file_request_received)
+
+    def pass_bytestream_disco(self, from_, identities, features, data, node):
+        if nbxmpp.NS_BYTESTREAM not in features:
+            return
+        if app.config.get_per('accounts', self.name, 'use_ft_proxies'):
+            log.info('Discovered proxy: %s', from_)
+            our_fjid = self.get_own_jid()
+            testit = app.config.get_per(
+                'accounts', self.name, 'test_ft_proxies_on_startup')
+            app.proxy65_manager.resolve(
+                from_, self.connection, str(our_fjid),
+                default=self.name, testit=testit)
+            raise nbxmpp.NodeProcessed
 
     def cleanup(self):
         app.ged.remove_event_handler('file-request-received', ged.GUI1,
@@ -191,10 +200,10 @@ class ConnectionBytestream:
         """
         Inform sender that we refuse to download the file
 
-        typ is used when code = '400', in this case typ can be 'strean' for
+        typ is used when code = '400', in this case typ can be 'stream' for
         invalid stream or 'profile' for invalid profile
         """
-        # user response to ConfirmationDialog may come after we've disconneted
+        # user response to ConfirmationDialog may come after we've disconnected
         if not self.connection or self.connected < 2:
             return
         if file_props.session_type == 'jingle':
@@ -329,7 +338,6 @@ class ConnectionSocks5Bytestream(ConnectionBytestream):
         if file_props is None:
             return
         self.disconnect_transfer(file_props)
-        sid = file_props.sid
 
     def disconnect_transfer(self, file_props):
         if file_props is None:
@@ -376,7 +384,7 @@ class ConnectionSocks5Bytestream(ConnectionBytestream):
             self._add_local_ips_as_streamhosts_to_query(query, file_props)
             self._add_proxy_streamhosts_to_query(query, file_props)
             self._add_upnp_igd_as_streamhost_to_query(query, file_props, iq)
-            # Upnp-igd is ascynchronous, so it will send the iq itself
+            # Upnp-igd is asynchronous, so it will send the iq itself
 
     def _add_streamhosts_to_query(self, query, sender, port, hosts):
         for host in hosts:
@@ -402,7 +410,7 @@ class ConnectionSocks5Bytestream(ConnectionBytestream):
         except socket.gaierror:
             from gajim.common.connection_handlers_events import InformationEvent
             app.nec.push_incoming_event(
-                InformationEvent(None, dialog_name='wrong-host')),
+                InformationEvent(None, dialog_name='wrong-host'))
 
     def _add_addiditional_streamhosts_to_query(self, query, file_props):
         sender = file_props.sender
@@ -416,7 +424,7 @@ class ConnectionSocks5Bytestream(ConnectionBytestream):
         self._add_streamhosts_to_query(query, sender, port, additional_hosts)
 
     def _add_upnp_igd_as_streamhost_to_query(self, query, file_props, iq):
-        if not app.HAVE_UPNP_IGD:
+        if not app.is_installed('UPNP'):
             self.connection.send(iq)
             return
 
@@ -425,7 +433,7 @@ class ConnectionSocks5Bytestream(ConnectionBytestream):
         # check if we are connected with an IPv4 address
         try:
             socket.inet_aton(my_ip)
-        except socket.error as e:
+        except socket.error:
             self.connection.send(iq)
             return
 
@@ -487,7 +495,7 @@ class ConnectionSocks5Bytestream(ConnectionBytestream):
         def no_upnp_reply():
             log.debug('Got not GUPnP-IGD answer')
             # stop trying to use it
-            app.HAVE_UPNP_IGD = False
+            app.disable_dependency('UPNP')
             self.no_gupnp_reply_id = 0
             self.connection.send(iq)
             cleanup_gupnp()
@@ -546,8 +554,8 @@ class ConnectionSocks5Bytestream(ConnectionBytestream):
                 }
                 proxyhost_dicts.append(host_dict)
             return proxyhost_dicts
-        else:
-            return []
+
+        return []
 
     def _result_socks5_sid(self, sid, hash_id):
         """
@@ -769,7 +777,7 @@ class ConnectionIBBytestream(ConnectionBytestream):
         Handles streams state change. Used internally.
         """
         typ = stanza.getType()
-        log.debug('IBBIqHandler called typ->%s' % typ)
+        log.debug('IBBIqHandler called typ->%s', typ)
         if typ == 'set' and stanza.getTag('open'):
             self.StreamOpenHandler(conn, stanza)
         elif typ == 'set' and stanza.getTag('close'):
@@ -799,12 +807,12 @@ class ConnectionIBBytestream(ConnectionBytestream):
         err = None
         sid = stanza.getTagAttr('open', 'sid')
         blocksize = stanza.getTagAttr('open', 'block-size')
-        log.debug('StreamOpenHandler called sid->%s blocksize->%s' % (sid,
-            blocksize))
+        log.debug('StreamOpenHandler called sid->%s blocksize->%s',
+                  sid, blocksize)
         file_props = FilesProp.getFilePropByTransportSid(self.name, sid)
         try:
             blocksize = int(blocksize)
-        except:
+        except Exception:
             err = nbxmpp.ERR_BAD_REQUEST
         if not sid or not blocksize:
             err = nbxmpp.ERR_BAD_REQUEST
@@ -813,7 +821,8 @@ class ConnectionIBBytestream(ConnectionBytestream):
         if err:
             rep = nbxmpp.Error(stanza, err)
         else:
-            log.debug("Opening stream: id %s, block-size %s" % (sid, blocksize))
+            log.debug("Opening stream: id %s, block-size %s",
+                      sid, blocksize)
             rep = nbxmpp.Protocol('iq', stanza.getFrom(), 'result',
                 stanza.getTo(), {'id': stanza.getID()})
             file_props.block_size = blocksize
@@ -855,7 +864,7 @@ class ConnectionIBBytestream(ConnectionBytestream):
 
     def OpenStream(self, sid, to, fp, blocksize=4096):
         """
-        Start new stream. You should provide stream id 'sid', the endpoind jid
+        Start new stream. You should provide stream id 'sid', the endpoint jid
         'to', the file object containing info for send 'fp'. Also the desired
         blocksize can be specified.
         Take into account that recommended stanza size is 4k and IBB uses
@@ -925,7 +934,7 @@ class ConnectionIBBytestream(ConnectionBytestream):
         sid = stanza.getTagAttr('data', 'sid')
         seq = stanza.getTagAttr('data', 'seq')
         data = stanza.getTagData('data')
-        log.debug('ReceiveHandler called sid->%s seq->%s' % (sid, seq))
+        log.debug('ReceiveHandler called sid->%s seq->%s', sid, seq)
         try:
             seq = int(seq)
             data = base64.b64decode(data.encode('utf-8'))
@@ -942,8 +951,8 @@ class ConnectionIBBytestream(ConnectionBytestream):
             elif seq != file_props.seq:
                 err = nbxmpp.ERR_UNEXPECTED_REQUEST
             else:
-                log.debug('Successfull receive sid->%s %s+%s bytes' % (sid,
-                    file_props.fp.tell(), len(data)))
+                log.debug('Successfully received sid->%s %s+%s bytes',
+                          sid, file_props.fp.tell(), len(data))
                 file_props.seq += 1
                 file_props.started = True
                 file_props.fp.write(data)
@@ -955,7 +964,7 @@ class ConnectionIBBytestream(ConnectionBytestream):
                 if file_props.received_len >= file_props.size:
                     file_props.completed = True
         if err:
-            log.debug('Error on receive: %s' % err)
+            log.debug('Error on receive: %s', err)
             conn.send(nbxmpp.Error(nbxmpp.Iq(to=stanza.getFrom(),
                 frm=stanza.getTo(),
                 payload=[nbxmpp.Node(nbxmpp.NS_IBB + ' close')]), err, reply=0))
@@ -965,10 +974,10 @@ class ConnectionIBBytestream(ConnectionBytestream):
     def StreamCloseHandler(self, conn, stanza):
         """
         Handle stream closure due to all data transmitted.
-        Raise xmpppy event specifying successfull data receive.
+        Raise xmpppy event specifying successful data receive.
         """
         sid = stanza.getTagAttr('close', 'sid')
-        log.debug('StreamCloseHandler called sid->%s' % sid)
+        log.debug('StreamCloseHandler called sid->%s', sid)
         # look in sending files
         file_props = FilesProp.getFilePropByTransportSid(self.name, sid)
         if file_props:
@@ -989,11 +998,11 @@ class ConnectionIBBytestream(ConnectionBytestream):
         """
         Handle remote side reply about if it agree or not to receive our
         datastream.
-        Used internally. Raises xmpppy event specfiying if the data transfer
+        Used internally. Raises xmpppy event specifying if the data transfer
         is agreed upon.
         """
         syn_id = stanza.getID()
-        log.debug('IBBAllIqHandler called syn_id->%s' % syn_id)
+        log.debug('IBBAllIqHandler called syn_id->%s', syn_id)
         for file_props in FilesProp.getAllFileProp():
             if not file_props.direction or not file_props.connected:
                 # It's socks5 bytestream
